==> component-redis-1.1.0-20181011.071746-5-sources.jar: com/bxm/newidea/component/redis/impl/RedisKeyGenerator.java <==
package com.bxm.newidea.component.redis.impl;

import com.bxm.newidea.component.redis.KeyGenerator;

/**
 * @author xiangui
 * 描述:
 * 时间: Create in 10:26 2018/6/20
 */
public class RedisKeyGenerator implements KeyGenerator {

    private String key;

    private String group;

    private String module;

    private RedisKeyGenerator(String key) {
        this.key = key;
    }

    private RedisKeyGenerator(String group, String key) {
        this.group = group;
        this.key = key;
    }

    private RedisKeyGenerator() {
    }

    public static RedisKeyGenerator build() {
        return new RedisKeyGenerator();
    }

    public static RedisKeyGenerator build(String key) {
        return new RedisKeyGenerator(key);
    }

    public static RedisKeyGenerator build(String group, String key) {
        return new RedisKeyGenerator(group, key);
    }

    @Override
    public RedisKeyGenerator setModule(String module) {
        this.module = module;
        return this;
    }

    @Override
    public RedisKeyGenerator setGroup(String group) {
        this.group = group;
        return this;
    }

    @Override
    public RedisKeyGenerator setKey(String key) {
        this.key = key;
        return this;
    }

    @Override
    public String gen() {
        String key = "";
        if (this.module != null) {
            key = this.module + ":";
        }
        if (this.group != null) {
            key = this.group + ":";
        }
        return key + this.key;
    }

    @Override
    public RedisKeyGenerator copy() {
        return RedisKeyGenerator.build(this.key);
    }
}

==> component-redis-1.1.0-20181018.082205-8-sources.jar: com/bxm/newidea/component/redis/impl/RedisKeyGenerator.java <==
package com.bxm.newidea.component.redis.impl;

import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.tools.StringUtils;

/**
 * @author xiangui
 * 描述:
 * 时间: Create in 10:26 2018/6/20
 */
public class RedisKeyGenerator implements KeyGenerator {

    private String key;

    private String group;

    private String module;

    private RedisKeyGenerator(String key) {
        this.key = key;
    }

    private RedisKeyGenerator(String group, String key) {
        this.group = group;
        this.key = key;
    }

    private RedisKeyGenerator() {
    }

    public static RedisKeyGenerator build() {
        return new RedisKeyGenerator();
    }

    public static RedisKeyGenerator build(String key) {
        return new RedisKeyGenerator(key);
    }

    public static RedisKeyGenerator build(String group, String key) {
        return new RedisKeyGenerator(group, key);
    }

    @Override
    public RedisKeyGenerator setModule(String module) {
        this.module = module;
        return this;
    }

    @Override
    public RedisKeyGenerator setGroup(String group) {
        this.group = group;
        return this;
    }

    @Override
    public RedisKeyGenerator setKey(String key) {
        this.key = key;
        return this;
    }

    @Override
    public KeyGenerator appendKey(Object subKey) {
        if (StringUtils.isBlank(key)) {
            this.key = subKey.toString();
        } else {
            this.key += JOIN_CHAR + subKey;
        }
        return this;
    }

    @Override
    public String gen() {
        String key = "";
        if (this.module != null) {
            key = this.module + JOIN_CHAR;
        }
        if (this.group != null) {
            key = this.group + JOIN_CHAR;
        }
        return key + this.key;
    }

    @Override
    public RedisKeyGenerator copy() {
        return RedisKeyGenerator.build(this.key);
    }

}
